==> wapi-python-0.7.2.tar.gz: wapi-python-0.7.2/README.md <==
# wapi-python
Wattsight API python library

This library is meant as a simple toolkit for working with data from
https://api.wattsight.com/ (or equivalent services).  Note that access
is based on some sort of login credentials, this library is not all
that useful unless you have a valid Wattsight account.

The library is tested against both Python 2.7 and Python 3.6,
we recommend using Python 3.


## Documentation

The 
[documentation](https://wattsight-wapi-python.readthedocs-hosted.com/en/latest/) 
with various 
[examples](https://wattsight-wapi-python.readthedocs-hosted.com/en/latest/examples.html)
is hosted on Read the Docs.

## Installation

You can simply install/update the latest version of Wattsight API python
library with pip.
Start a terminal (a shell) and use the following command

```bash
pip install -U wapi-python
```

## Copyright (MIT License)

Copyright (c) 2018-2019 Wattsight AS

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> wapi-python-0.7.15.tar.gz: wapi-python-0.7.15/README.md <==
# wapi-python
Wattsight API python library

This library is meant as a simple toolkit for working with data from
https://api.volueinsight.com/ (or equivalent services).  Note that access
is based on some sort of login credentials, this library is not all
that useful unless you have a valid Wattsight account.

The library is tested against both Python version >=3.5 and <=3.9


## Documentation

The 
[documentation](https://wattsight-wapi-python.readthedocs-hosted.com/en/latest/) 
with various 
[examples](https://wattsight-wapi-python.readthedocs-hosted.com/en/latest/examples.html)
is hosted on Read the Docs.

## Installation

You can simply install/update the latest version of Wattsight API python
library with pip.
Start a terminal (a shell) and use the following command

```bash
pip install -U wapi-python
```

## Copyright (MIT License)

Copyright (c) 2018-2019 Wattsight AS

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
